==> test-superset-2-1.0.1.tgz: package/esm/TestSuperset2.js <==
var _templateObject;

function _taggedTemplateLiteralLoose(strings, raw) { if (!raw) { raw = strings.slice(0); } strings.raw = raw; return strings; }

/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
import React, { useEffect, createRef, useState } from 'react';
import { styled } from '@superset-ui/core';
import defaultUser from "./images/defaultUser.png"; // The following Styles component is a <div> element, which has been styled using Emotion
// For docs, visit https://emotion.sh/docs/styled
// Theming variables are provided for your use via a ThemeProvider
// imported from @superset-ui/core. For variables available, please visit
// https://github.com/apache-superset/superset-ui/blob/master/packages/superset-ui-core/src/style/index.ts

var Styles = styled.div(_templateObject || (_templateObject = _taggedTemplateLiteralLoose(["\n  background-color: ", ";\n  padding: ", "px;\n  border-radius: ", "px;\n  height: ", "px;\n  width: ", "px;\n\n  h3 {\n    /* You can use your props to control CSS! */\n    margin-top: 0;\n    margin-bottom: ", "px;\n    font-size: ", "px;\n    font-weight: ", ";\n  }\n\n  pre {\n    height: ", "px;\n  }\n"])), _ref => {
  var {
    theme
  } = _ref;
  return theme.colors.secondary.light2;
}, _ref2 => {
  var {
    theme
  } = _ref2;
  return theme.gridUnit * 4;
}, _ref3 => {
  var {
    theme
  } = _ref3;
  return theme.gridUnit * 2;
}, _ref4 => {
  var {
    height
  } = _ref4;
  return height;
}, _ref5 => {
  var {
    width
  } = _ref5;
  return width;
}, _ref6 => {
  var {
    theme
  } = _ref6;
  return theme.gridUnit * 3;
}, _ref7 => {
  var {
    theme,
    headerFontSize
  } = _ref7;
  return theme.typography.sizes[headerFontSize];
}, _ref8 => {
  var {
    theme,
    boldText
  } = _ref8;
  return theme.typography.weights[boldText ? 'bold' : 'normal'];
}, _ref9 => {
  var {
    theme,
    headerFontSize,
    height
  } = _ref9;
  return height - theme.gridUnit * 12 - theme.typography.sizes[headerFontSize];
});
/**
 * ******************* WHAT YOU CAN BUILD HERE *******************
 *  In essence, a chart is given a few key ingredients to work with:
 *  * Data: provided via `props.data`
 *  * A DOM element
 *  * FormData (your controls!) provided as props by transformProps.ts
 */

export default function TestSuperset2(props) {
  // height and width are the height and width of the DOM element as it exists in the dashboard.
  // There is also a `data` prop, which is, of course, your DATA 🎉
  var {
    data,
    height,
    width
  } = props;
  var [orderBy, setOrderBy] = useState("engagement");
  var rootElem = /*#__PURE__*/createRef(); // Often, you just want to access the DOM and do whatever you want.
  // Here, you can do that with createRef, and the useEffect hook.   boxShadow: "rgba(0, 0, 0, 0.16) 0px 1px 4px"
  // const {state} = useSupersetContext();

  useEffect(() => {
    var root = rootElem.current;
    console.log('Plugin element', data, root);
  });
  useEffect(() => {
    data.sort((a, b) => {
      if (a[orderBy] < b[orderBy]) {
        return -1;
      }

      if (a[orderBy] > b[orderBy]) {
        return 1;
      }

      return 0;
    });
  }, [orderBy]);
  console.log('Plugin props', props);
  return /*#__PURE__*/React.createElement(Styles, {
    ref: rootElem,
    boldText: props.boldText,
    headerFontSize: props.headerFontSize,
    height: height,
    width: width,
    style: {
      background: "white"
    }
  }, /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement("div", {
    style: {
      display: "flex",
      flexDirection: "column",
      color: "#686d71",
      margin: "auto"
    }
  }, /*#__PURE__*/React.createElement("div", {
    style: {
      display: "flex",
      justifyContent: "space-between",
      borderBottom: "1px solid #ecedef",
      height: "100px",
      alignItems: "center"
    }
  }, /*#__PURE__*/React.createElement("div", {
    style: {
      width: "30%"
    }
  }, /*#__PURE__*/React.createElement("p", {
    style: {
      color: "#fd7302",
      fontSize: "25px",
      textAlign: "left"
    }
  }, "POSICIONAMIENTO ")), /*#__PURE__*/React.createElement("div", {
    style: {
      width: "23%",
      cursor: "pointer"
    },
    onClick: () => setOrderBy("publicaciones")
  }, /*#__PURE__*/React.createElement("div", {
    style: {
      borderBottom: orderBy == "publicaciones" ? "2px solid #007fae" : "",
      maxWidth: "100px",
      margin: "auto"
    }
  }, /*#__PURE__*/React.createElement("p", {
    style: {
      fontWeight: orderBy == "publicaciones" ? "700" : "",
      color: orderBy == "publicaciones" ? "#007fae" : ""
    }
  }, "Publicaciones"))), /*#__PURE__*/React.createElement("div", {
    style: {
      width: "23%",
      cursor: "pointer"
    },
    onClick: () => setOrderBy("interacciones")
  }, /*#__PURE__*/React.createElement("div", {
    style: {
      borderBottom: orderBy == "interacciones" ? "2px solid #007fae" : "",
      maxWidth: "100px",
      margin: "auto"
    }
  }, /*#__PURE__*/React.createElement("p", {
    style: {
      fontWeight: orderBy == "interacciones" ? "700" : "",
      color: orderBy == "interacciones" ? "#007fae" : ""
    }
  }, "Interacciones"))), /*#__PURE__*/React.createElement("div", {
    style: {
      width: "23%",
      cursor: "pointer"
    },
    onClick: () => setOrderBy("engagement")
  }, /*#__PURE__*/React.createElement("div", {
    style: {
      borderBottom: orderBy == "engagement" ? "2px solid #007fae" : "",
      maxWidth: "100px",
      margin: "auto"
    }
  }, /*#__PURE__*/React.createElement("p", {
    style: {
      fontWeight: orderBy == "engagement" ? "700" : "",
      color: orderBy == "engagement" ? "#007fae" : ""
    }
  }, "Engagement")))), /*#__PURE__*/React.createElement("div", {
    style: {
      maxHeight: "700px",
      overflowY: "scroll"
    }
  }, data.map((metric, index) => {
    var _metric$publicaciones, _metric$publicaciones2, _metric$interacciones, _metric$interacciones2, _metric$engagement$to, _metric$engagement;

    return /*#__PURE__*/React.createElement("div", {
      key: index,
      style: {
        display: "flex",
        justifyContent: "space-between",
        margin: "auto",
        marginTop: "10px",
        marginBottom: "15px",
        alignItems: "center",
        background: "rgb(249, 249, 249)",
        padding: "5px",
        borderRadius: "10px",
        width: "98%",
        height: "125px"
      }
    }, /*#__PURE__*/React.createElement("div", {
      style: {
        width: "30%",
        display: "flex",
        justifyContent: "flex-start",
        alignItems: "center"
      }
    }, /*#__PURE__*/React.createElement("div", {
      style: {
        width: "35%"
      }
    }, /*#__PURE__*/React.createElement("p", {
      style: {
        fontSize: "18px",
        marginRight: "20px"
      }
    }, index + 1)), /*#__PURE__*/React.createElement("img", {
      src: defaultUser,
      alt: "profile",
      style: {
        width: "90px",
        height: "90px",
        borderRadius: "50%",
        boxShadow: "inset 0 2px 4px 0 hsla(0,0%,0%, .2)",
        borderRight: "3px solid #feb981"
      }
    }), /*#__PURE__*/React.createElement("div", {
      style: {
        flexGrow: "1",
        height: "1px",
        marginTop: "5px",
        marginBottom: "5px",
        background: "#feb981"
      }
    }, " ")), /*#__PURE__*/React.createElement("div", {
      style: {
        width: "70%",
        height: "100%",
        display: "flex",
        flexDirection: "column"
      }
    }, /*#__PURE__*/React.createElement("div", {
      style: {
        width: "100%",
        height: "50%",
        display: "flex",
        justifyContent: "center",
        alignItems: "center"
      }
    }, /*#__PURE__*/React.createElement("p", {
      style: {
        color: "black",
        fontSize: "16px",
        textAlign: "center"
      }
    }, metric.username)), /*#__PURE__*/React.createElement("div", {
      style: {
        width: "100%",
        height: "1px",
        marginTop: "5px",
        marginBottom: "5px",
        background: "#feb981"
      }
    }), /*#__PURE__*/React.createElement("div", {
      style: {
        width: "100%",
        height: "50%",
        display: "flex"
      }
    }, /*#__PURE__*/React.createElement("div", {
      style: {
        width: "33%",
        textAlign: "center",
        display: "flex",
        justifyContent: "center",
        alignItems: "center"
      }
    }, /*#__PURE__*/React.createElement("p", null, (_metric$publicaciones = (_metric$publicaciones2 = metric.publicaciones) == null ? void 0 : _metric$publicaciones2.toLocaleString('en')) != null ? _metric$publicaciones : "-")), /*#__PURE__*/React.createElement("div", {
      style: {
        width: "33%",
        textAlign: "center",
        display: "flex",
        justifyContent: "center",
        alignItems: "center"
      }
    }, /*#__PURE__*/React.createElement("p", null, (_metric$interacciones = (_metric$interacciones2 = metric.interacciones) == null ? void 0 : _metric$interacciones2.toLocaleString('en')) != null ? _metric$interacciones : "-")), /*#__PURE__*/React.createElement("div", {
      style: {
        width: "33%",
        textAlign: "center",
        display: "flex",
        justifyContent: "center",
        alignItems: "center"
      }
    }, /*#__PURE__*/React.createElement("p", null, (_metric$engagement$to = (_metric$engagement = metric.engagement) == null ? void 0 : _metric$engagement.toLocaleString('en')) != null ? _metric$engagement$to : "-")))));
  })))));
}

==> test-superset-2-1.0.3.tgz: package/esm/TestSuperset2.js <==
var _templateObject;

function _taggedTemplateLiteralLoose(strings, raw) { if (!raw) { raw = strings.slice(0); } strings.raw = raw; return strings; }

/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
import React, { useEffect, createRef, useState } from 'react';
import { styled } from '@superset-ui/core';
// The following Styles component is a <div> element, which has been styled using Emotion
// For docs, visit https://emotion.sh/docs/styled
// Theming variables are provided for your use via a ThemeProvider
// imported from @superset-ui/core. For variables available, please visit
// https://github.com/apache-superset/superset-ui/blob/master/packages/superset-ui-core/src/style/index.ts
var Styles = styled.div(_templateObject || (_templateObject = _taggedTemplateLiteralLoose(["\n  background-color: ", ";\n  padding: ", "px;\n  border-radius: ", "px;\n  height: ", "px;\n  width: ", "px;\n\n  h3 {\n    /* You can use your props to control CSS! */\n    margin-top: 0;\n    margin-bottom: ", "px;\n    font-size: ", "px;\n    font-weight: ", ";\n  }\n\n  pre {\n    height: ", "px;\n  }\n"])), _ref => {
  var {
    theme
  } = _ref;
  return theme.colors.secondary.light2;
}, _ref2 => {
  var {
    theme
  } = _ref2;
  return theme.gridUnit * 4;
}, _ref3 => {
  var {
    theme
  } = _ref3;
  return theme.gridUnit * 2;
}, _ref4 => {
  var {
    height
  } = _ref4;
  return height;
}, _ref5 => {
  var {
    width
  } = _ref5;
  return width;
}, _ref6 => {
  var {
    theme
  } = _ref6;
  return theme.gridUnit * 3;
}, _ref7 => {
  var {
    theme,
    headerFontSize
  } = _ref7;
  return theme.typography.sizes[headerFontSize];
}, _ref8 => {
  var {
    theme,
    boldText
  } = _ref8;
  return theme.typography.weights[boldText ? 'bold' : 'normal'];
}, _ref9 => {
  var {
    theme,
    headerFontSize,
    height
  } = _ref9;
  return height - theme.gridUnit * 12 - theme.typography.sizes[headerFontSize];
});
/**
 * ******************* WHAT YOU CAN BUILD HERE *******************
 *  In essence, a chart is given a few key ingredients to work with:
 *  * Data: provided via `props.data`
 *  * A DOM element
 *  * FormData (your controls!) provided as props by transformProps.ts
 */

export default function TestSuperset2(props) {
  // height and width are the height and width of the DOM element as it exists in the dashboard.
  // There is also a `data` prop, which is, of course, your DATA 🎉
  var {
    data,
    height,
    width
  } = props;
  var [orderBy, setOrderBy] = useState("engagement");
  var rootElem = /*#__PURE__*/createRef(); // Often, you just want to access the DOM and do whatever you want.
  // Here, you can do that with createRef, and the useEffect hook.   boxShadow: "rgba(0, 0, 0, 0.16) 0px 1px 4px"
  // const {state} = useSupersetContext();

  useEffect(() => {
    var root = rootElem.current;
    console.log('Plugin element', data, root);
  });
  useEffect(() => {
    data.sort((a, b) => {
      if (a[orderBy] < b[orderBy]) {
        return -1;
      }

      if (a[orderBy] > b[orderBy]) {
        return 1;
      }

      return 0;
    });
  }, [orderBy]);
  console.log('Plugin props', props);
  return /*#__PURE__*/React.createElement(Styles, {
    ref: rootElem,
    boldText: props.boldText,
    headerFontSize: props.headerFontSize,
    height: height,
    width: width,
    style: {
      background: "white"
    }
  }, /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement("div", {
    style: {
      display: "flex",
      flexDirection: "column",
      color: "#686d71",
      margin: "auto"
    }
  }, /*#__PURE__*/React.createElement("div", {
    style: {
      display: "flex",
      justifyContent: "space-between",
      borderBottom: "1px solid #ecedef",
      height: "100px",
      alignItems: "center"
    }
  }, /*#__PURE__*/React.createElement("div", {
    style: {
      width: "30%"
    }
  }, /*#__PURE__*/React.createElement("p", {
    style: {
      color: "#fd7302",
      fontSize: "25px",
      textAlign: "left"
    }
  }, " ")), /*#__PURE__*/React.createElement("div", {
    style: {
      width: "23%",
      cursor: "pointer"
    },
    onClick: () => setOrderBy("publicaciones")
  }, /*#__PURE__*/React.createElement("div", {
    style: {
      borderBottom: orderBy == "publicaciones" ? "2px solid #007fae" : "",
      maxWidth: "100px",
      margin: "auto"
    }
  }, /*#__PURE__*/React.createElement("p", {
    style: {
      fontWeight: orderBy == "publicaciones" ? "700" : "",
      color: orderBy == "publicaciones" ? "#007fae" : ""
    }
  }, "Publicaciones"))), /*#__PURE__*/React.createElement("div", {
    style: {
      width: "23%",
      cursor: "pointer"
    },
    onClick: () => setOrderBy("interacciones")
  }, /*#__PURE__*/React.createElement("div", {
    style: {
      borderBottom: orderBy == "interacciones" ? "2px solid #007fae" : "",
      maxWidth: "100px",
      margin: "auto"
    }
  }, /*#__PURE__*/React.createElement("p", {
    style: {
      fontWeight: orderBy == "interacciones" ? "700" : "",
      color: orderBy == "interacciones" ? "#007fae" : ""
    }
  }, "Interacciones"))), /*#__PURE__*/React.createElement("div", {
    style: {
      width: "23%",
      cursor: "pointer"
    },
    onClick: () => setOrderBy("engagement")
  }, /*#__PURE__*/React.createElement("div", {
    style: {
      borderBottom: orderBy == "engagement" ? "2px solid #007fae" : "",
      maxWidth: "100px",
      margin: "auto"
    }
  }, /*#__PURE__*/React.createElement("p", {
    style: {
      fontWeight: orderBy == "engagement" ? "700" : "",
      color: orderBy == "engagement" ? "#007fae" : ""
    }
  }, "Engagement")))), /*#__PURE__*/React.createElement("div", {
    style: {
      maxHeight: "700px",
      overflowY: "scroll"
    }
  }, data.map((metric, index) => {
    var _metric$publicaciones, _metric$publicaciones2, _metric$interacciones, _metric$interacciones2, _metric$engagement$to, _metric$engagement;

    return /*#__PURE__*/React.createElement("div", {
      key: index,
      style: {
        display: "flex",
        justifyContent: "space-between",
        margin: "auto",
        marginTop: "10px",
        marginBottom: "15px",
        alignItems: "center",
        background: "rgb(249, 249, 249)",
        padding: "5px",
        borderRadius: "10px",
        width: "98%",
        height: "125px"
      }
    }, /*#__PURE__*/React.createElement("div", {
      style: {
        width: "30%",
        display: "flex",
        justifyContent: "flex-start",
        alignItems: "center"
      }
    }, /*#__PURE__*/React.createElement("div", {
      style: {
        width: "35%"
      }
    }, /*#__PURE__*/React.createElement("p", {
      style: {
        fontSize: "18px",
        marginRight: "20px"
      }
    }, index + 1)), /*#__PURE__*/React.createElement("img", {
      src: metric.pageId,
      alt: "profile",
      style: {
        width: "90px",
        height: "90px",
        borderRadius: "50%",
        boxShadow: "inset 0 2px 4px 0 hsla(0,0%,0%, .2)",
        borderRight: "3px solid #feb981"
      }
    }), /*#__PURE__*/React.createElement("div", {
      style: {
        flexGrow: "1",
        height: "1px",
        marginTop: "5px",
        marginBottom: "5px",
        background: "#feb981"
      }
    }, " ")), /*#__PURE__*/React.createElement("div", {
      style: {
        width: "70%",
        height: "100%",
        display: "flex",
        flexDirection: "column"
      }
    }, /*#__PURE__*/React.createElement("div", {
      style: {
        width: "100%",
        height: "50%",
        display: "flex",
        justifyContent: "center",
        alignItems: "center"
      }
    }, /*#__PURE__*/React.createElement("p", {
      style: {
        color: "black",
        fontSize: "16px",
        textAlign: "center"
      }
    }, metric.username)), /*#__PURE__*/React.createElement("div", {
      style: {
        width: "100%",
        height: "1px",
        marginTop: "5px",
        marginBottom: "5px",
        background: "#feb981"
      }
    }), /*#__PURE__*/React.createElement("div", {
      style: {
        width: "100%",
        height: "50%",
        display: "flex"
      }
    }, /*#__PURE__*/React.createElement("div", {
      style: {
        width: "33%",
        textAlign: "center",
        display: "flex",
        justifyContent: "center",
        alignItems: "center"
      }
    }, /*#__PURE__*/React.createElement("p", null, (_metric$publicaciones = (_metric$publicaciones2 = metric.publicaciones) == null ? void 0 : _metric$publicaciones2.toLocaleString('en')) != null ? _metric$publicaciones : "-")), /*#__PURE__*/React.createElement("div", {
      style: {
        width: "33%",
        textAlign: "center",
        display: "flex",
        justifyContent: "center",
        alignItems: "center"
      }
    }, /*#__PURE__*/React.createElement("p", null, (_metric$interacciones = (_metric$interacciones2 = metric.interacciones) == null ? void 0 : _metric$interacciones2.toLocaleString('en')) != null ? _metric$interacciones : "-")), /*#__PURE__*/React.createElement("div", {
      style: {
        width: "33%",
        textAlign: "center",
        display: "flex",
        justifyContent: "center",
        alignItems: "center"
      }
    }, /*#__PURE__*/React.createElement("p", null, (_metric$engagement$to = (_metric$engagement = metric.engagement) == null ? void 0 : _metric$engagement.toLocaleString('en')) != null ? _metric$engagement$to : "-")))));
  })))));
}
